@@ -2,7 +2,7 @@ package Dezi;
 use warnings;
 use strict;
 
-our $VERSION = '0.002998_01';
+our $VERSION = '0.001000';
 
 1;
 
@@ -10,7 +10,7 @@ __END__
 
 =head1 NAME
 
-Dezi - REST search platform
+Dezi - search platform based on Apache Lucy, Swish3, Search::OpenSearch and Plack
 
 =head1 SYNOPSIS
 
@@ -20,62 +20,27 @@ Start the Dezi server, listening on port 5000:
 
 Add a document B<foo> to the index:
 
- % curl http://localhost:5000/index/foo -XPOST \
+ % curl -XPOST http://localhost:5000/foo \
    -d '<doc><title>bar</title>hello world</doc>' \
    -H 'Content-Type: application/xml'
    
-Search the index for B<bar>:
+Search the index:
 
- % curl 'http://localhost:5000/search?q=bar&t=JSON'
- % curl 'http://localhost:5000/search?q=bar&t=XML'
- 
-Read the usage statement:
-
- % dezi -h
+ % curl 'http://localhost:5000/?q=bar&format=json'
+ % curl 'http://localhost:5000/?q=bar&format=xml'
 
 =head1 DESCRIPTION
 
-Dezi is a search platform based on Apache L<Lucy>, Swish3,
-L<Search::OpenSearch> and L<Search::Query>. 
+Dezi is a search platform based on Apache Lucy, Swish3,
+Search::OpenSearch and Search::Query. 
 
 Dezi integrates several CPAN search libraries into one
 easy-to-use interface.
 
-This document is a placeholder for the namespace and documentation
-only. You should read:
-
-=over
-
-=item
-
-the L<Dezi::Tutorial>
-
-=item
-
-the L<Dezi::Server> class documentation
-
-=item
-
-the L<Dezi::Architecture>
-
-=item
-
-the L<Search::OpenSearch::Server::Plack> documentation, upon which
-Dezi relies heavily.
-
-=back
-
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
 
-=head1 ACKNOWLEDGEMENTS
-
-Many of the code ideas in Dezi were developed
-while working on search-related projects for the
-Public Insight Network at American Public Media.
-L<http://www.publicinsightnetwork.org>.
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi at rt.cpan.org>, or through
@@ -93,18 +58,6 @@ You can also look for information at:
 
 =over 4
 
-=item * Website
-
-L<http://dezi.org/>
-
-=item * IRC
-
-#dezisearch at freenode
-
-=item * Mailing list
-
-L<https://groups.google.com/forum/#!forum/dezi-search>
-
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dezi>
@@ -136,6 +89,6 @@ See http://dev.perl.org/licenses/ for more information.
 =head1 SEE ALSO
 
 L<Search::OpenSearch>, L<SWISH::3>, L<SWISH::Prog::Lucy>,
-L<Plack>, L<Lucy>, L<http://dezi.org>
+L<Plack>, L<Lucy>
 
 =cut
